naima
=====

``naima`` uses MCMC fitting of non-thermal X-ray, GeV, and TeV spectra to
constrain the properties of their parent relativistic particle distributions.
The workhorse of ``naima`` is the powerful `emcee <http://dan.iel.fm/emcee>`_
affine-invariant ensemble sampler for Markov chain Monte Carlo.

Documentation is at `naima.readthedocs.org
<http://naima.readthedocs.org>`_.


.. image:: http://travis-ci.org/zblz/naima.svg
   :target: https://travis-ci.org/zblz/naima

.. image:: http://coveralls.io/repos/zblz/naima/badge.png
   :target: https://coveralls.io/r/zblz/naima
